pub enum Alignment {
    Begin,
    Center,
    End,
    Expand,
}
A struct representing horizontal/vertical alignment

Variants

Begin

The object should be aligned at the begining of the axis

Center

The object should be centered on the axis

End

The object should be at the end of the axis.

Expand

The object should take us much space as possible on the axis

Implementations

Aligns a given axis